@@ -1,16 +1,13 @@
 package File::Open;
 
+use warnings; use warnings FATAL => qw(layer);
 use strict;
-use warnings;
-BEGIN { warnings->import(FATAL => 'layer') if $] >= 5.008; }
 
-our $VERSION = '0.100_01';
-$VERSION = eval $VERSION;
+our $VERSION = '0.02';
 
 use File::Basename qw(basename);
 use Carp qw(croak);
 use Fcntl ();
-use Errno ();
 use Exporter qw(import);
 
 our @EXPORT;
@@ -37,20 +34,9 @@ sub _open {
 	my $b = $mode =~ s/(?<=.)b//;
 	my $emode = $modemap{$mode} or croak "Unknown $func() mode '$mode'";
 
-	if ($file =~ /\0/) {
-		$! = Errno::ENOENT() if exists &Errno::ENOENT;
-		return undef;
-	}
-
-	unless (defined $layers) {
-		# grab our caller's 'use open' settings
-		my $hints = (caller 1)[10];
-		my $key = $emode =~ />/ ? 'open>' : 'open<';
-		$layers = $hints->{$key};
-	}
-
-	open my $fh, $emode . (defined $layers ? " $layers" : ''), $file or return undef;
+	open my $fh, $emode, $file or return undef;
 	binmode $fh if $b;
+	binmode $fh, $layers if defined $layers;
 	$fh
 }
 
@@ -72,9 +58,9 @@ sub _sysopen {
 	@_ > 4 and croak "Too many arguments for $func";
 
 	my $emode =
-		$mode eq 'r' ? Fcntl::O_RDONLY() :
-		$mode eq 'w' ? Fcntl::O_WRONLY() :
-		$mode eq 'rw' ? Fcntl::O_RDWR() :
+		$mode eq 'r' ? Fcntl::O_RDONLY :
+		$mode eq 'w' ? Fcntl::O_WRONLY :
+		$mode eq 'rw' ? Fcntl::O_RDWR :
 		croak "Unknown $func() mode '$mode'"
 	;
 
@@ -106,11 +92,6 @@ sub _sysopen {
 		;
 	}
 
-	if ($file =~ /\0/) {
-		$! = Errno::ENOENT() if exists &Errno::ENOENT;
-		return undef;
-	}
-
 	sysopen my $fh, $file, $emode, $perms or return undef;
 	$fh
 }
@@ -209,27 +190,9 @@ This will cause L<binmode|perlfunc/binmode> to be called on the filehandle.
 
 If you don't specify a MODE, it defaults to C<'r'>.
 
-If you pass LAYERS, C<fopen> will combine it with the open mode in the
-underlying L<open|perlfunc/open> call. This gives you greater control than the
-simple C<'b'> in MODE (which is equivalent to passing C<:raw> as LAYERS). For
-example, to read from a UTF-8 file:
-
-  my $fh = fopen $file, 'r', ':encoding(UTF-8)';
-  # does
-  #   open my $fh, '<:encoding(UTF-8)', $file
-  # under the covers
- 
-  while (my $line = readline $fh) {
-      ...
-  }
-
-See L<PerlIO> and L<Encode::Supported> for a list of available layers and
-encoding names, respectively.
-
-If you don't pass LAYERS, C<fopen> will use the default layers set via
-C<use open ...>, if any (see L<open>). Default layers aren't supported on old
-perls (i.e. anything before 5.10.0); on those you'll have to pass an explicit
-LAYERS argument.
+If you pass LAYERS, C<fopen> will call C<binmode $fh, LAYERS> on the newly
+opened filehandle. This gives you greater control than the simple C<'b'> in
+MODE.
 
 =item fopen_nothrow FILE
 
@@ -302,38 +265,13 @@ it simply returns C<undef>.
 
 =back
 
-=head2 Methods
-
-The returned filehandles behave like L<IO::Handle> objects (actually
-L<IO::File> objects, which is a subclass of L<IO::Handle>). However, on perl
-versions before 5.14.0 you have to C<use IO::Handle;> manually before you can
-call any methods on them. (Current perl versions will do this for you
-automatically but it doesn't hurt to load L<IO::Handle> anyway.)
-
-Here is a toy example that copies all lines from one file to another, using
-method calls instead of functions:
-
-  use File::Open qw(fopen);
-  use IO::Handle;  # not needed on 5.14+
- 
-  my $fh_in  = fopen $file_in,  'r';
-  my $fh_out = fopen $file_out, 'w';
- 
-  while (defined(my $line = $fh_in->getline)) {
-      $fh_out->print($line) or die "$0: $file_out: $!\n";
-  }
- 
-  $fh_out->close or die "$0: $file_out: $!\n";
-  $fh_in->close;
-
 =head1 SEE ALSO
 
 L<perlfunc/open>,
 L<perlfunc/binmode>,
 L<perlfunc/sysopen>,
-L<perlopentut>,
-L<IO::Handle>,
 L<Fcntl>,
+L<perlopentut>,
 L<open(2)>
 
 =head1 AUTHOR
@@ -342,7 +280,7 @@ Lukas Mai, C<< <l.mai at web.de> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2011, 2013 Lukas Mai.
+Copyright 2011 Lukas Mai.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
